# This file is auto-generated by hatch-gradle-version. Do not edit.

GRADLE_VERSION = "0.9.2.4"
FULL_VERSION = "0.9.2.4.1.0"

ARS_VERSION = "4.12.5.243"
FORGE_VERSION = "47.3.6"
FORGE_VERSION_RANGE = "[47,)"
GECKO_VERSION = "4.4.4"
HEXCASTING_VERSION = "0.11.2-pre-702"
LOADER_VERSION_RANGE = "[47,)"
MAPPING_CHANNEL = "official"
MAPPING_VERSION = "1.20.1"
MINECRAFT_VERSION = "1.20.1"
MINECRAFT_VERSION_RANGE = "[1.20.1,1.21)"
MOD_AUTHORS = "YukkuriC"
MOD_DESCRIPTION = "Link Ars Nouveau mana to Hex Casting media"
MOD_GROUP_ID = "yukkuric"
MOD_ID = "hex_ars_link"
MOD_LICENSE = "MIT"
MOD_NAME = "Hex-Ars Linker"
MOD_VERSION = "DYNAMIC"
MOD_VERSION_BASE = "0.9.2.4"
ORG_GRADLE_DAEMON = "false"
ORG_GRADLE_JVMARGS = "-Xmx3G"
PATCHOULI_VERSION = "80-FORGE"
